@@ -80,7 +80,7 @@ class Connection(ABC):
         pass
 
     @abstractmethod
-    def get_datasets(self, data_model_id, columns):
+    def get_values(self, data_model_id, columns):
         pass
 
     @abstractmethod
@@ -95,10 +95,18 @@ class Connection(ABC):
     def get_data_count_by_dataset(self, schema_fullname):
         pass
 
+    @abstractmethod
+    def get_row_count(self, table):
+        pass
+
     @abstractmethod
     def drop_table(self, table):
         pass
 
+    @abstractmethod
+    def delete_table_values(self, table):
+        pass
+
     @abstractmethod
     def get_dataset_properties(self, dataset_id):
         pass
@@ -147,6 +155,10 @@ class Connection(ABC):
     def get_current_user(self):
         pass
 
+    @abstractmethod
+    def copy_csv_in_table(self, offset, table_name):
+        pass
+
 
 class DataBase(ABC):
     """Abstract class representing a database interface."""
@@ -179,10 +191,18 @@ class DataBase(ABC):
     def update_dataset_status(self, status, dataset_id):
         pass
 
+    @abstractmethod
+    def get_row_count(self, table):
+        pass
+
     @abstractmethod
     def drop_table(self, table):
         pass
 
+    @abstractmethod
+    def delete_table_values(self, table):
+        pass
+
     @abstractmethod
     def get_dataset_properties(self, dataset_id):
         pass
@@ -216,7 +236,7 @@ class DataBase(ABC):
         pass
 
     @abstractmethod
-    def get_datasets(self, data_model_id, columns):
+    def get_values(self, data_model_id, columns):
         pass
 
     @abstractmethod
@@ -259,6 +279,10 @@ class DataBase(ABC):
     def get_executor(self):
         pass
 
+    @abstractmethod
+    def copy_csv_in_table(self, offset, table_name):
+        pass
+
 
 def handle_errors(func):
     """Decorator for any function susceptible to raise a DB related exception.
@@ -418,6 +442,10 @@ class DBExecutorMixin(ABC):
         )
         return list(res)
 
+    def get_row_count(self, table):
+        res = self.execute(f"select COUNT(*) from {table}").fetchone()
+        return res[0]
+
     def get_dataset(self, dataset_id, columns):
         columns_query = ", ".join(columns) if columns else "*"
 
@@ -455,7 +483,7 @@ class DBExecutorMixin(ABC):
 
         return list(data_models)
 
-    def get_datasets(self, data_model_id=None, columns=None):
+    def get_values(self, data_model_id=None, columns=None):
         columns_query = ", ".join(columns) if columns else "*"
         data_model_id_clause = (
             f"WHERE data_model_id={data_model_id}" if data_model_id else ""
@@ -499,10 +527,48 @@ class DBExecutorMixin(ABC):
                         WHERE dataset_id = {dataset_id}"""
         self.execute(query)
 
+    def copy_csv_in_table(self, file_location, records, offset, table_name):
+        records_query = ""
+        if records:
+            records_query = f"{records} RECORDS"
+
+        copy_into_query = f"""
+            COPY {records_query} OFFSET {offset} INTO {table_name}
+            FROM '{file_location}'
+            USING DELIMITERS ',', E'\n', '\"'
+            NULL AS '';
+            """
+        self.execute(copy_into_query)
+
+    def copy_data_table_to_another_table(self, copy_into_table, copy_from_table):
+        # row_id is autoincrement, so we do not need to provide values.
+        table_column_names_without_row_id = [
+            column.name
+            for column in list(copy_into_table.table.columns)
+            if column.name != "row_id"
+        ]
+        csv_column_names = [
+            column.name for column in list(copy_from_table.table.columns)
+        ]
+        select_query_columns = [
+            f'"{column}"' if column in csv_column_names else "NULL"
+            for column in table_column_names_without_row_id
+        ]
+        self.execute(
+            f"""
+            INSERT INTO "{copy_into_table.table.schema}".{copy_into_table.table.name} ({','.join([f'"{column}"' for column in table_column_names_without_row_id])})
+            SELECT {', '.join(select_query_columns)}
+            FROM {copy_from_table.table.name};
+        """
+        )
+
     @handle_errors
     def drop_table(self, table):
         table.drop(bind=self._executor)
 
+    def delete_table_values(self, table):
+        self.execute(table.delete())
+
     def insert_values_to_table(self, table, values):
         self.execute(table.insert(), values)
 
